==> gcc-3.1.tar.gz: gcc-3.1/libjava/java/lang/ClassFormatError.java <==
/* ClassFormatError.java 
   Copyright (C) 1998, 1999, 2001 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.lang;

/* Written using "Java Class Libraries", 2nd edition, ISBN 0-201-31002-3
 * "The Java Language Specification", ISBN 0-201-63451-1
 * plus online API docs for JDK 1.2 beta from http://www.javasoft.com.
 * Status:  Believed complete and correct.
 */

/**
 * A <code>ClassFormatError</code> is thrown when a Java Virtual Machine 
 * unable to read a class file because the file is corrupted or cannot be
 * interpreted as a class file.
 *
 * @since JDK 1.0
 * 
 * @author Brian Jones
 */
public class ClassFormatError extends LinkageError
{
  static final long serialVersionUID = -8420114879011949195L;

  /**
   * Create an error without a message.
   */
  public ClassFormatError()
    {
      super();
    }

  /**
   * Create an error with a message.
   */
  public ClassFormatError(String s)
    {
      super(s);
    }
}

==> gcc-3.3.2.tar.gz: gcc-3.3.2/libjava/java/lang/ClassFormatError.java <==
/* ClassFormatError.java -- thrown if a class file is invalid
   Copyright (C) 1998, 1999, 2001, 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.lang;

/**
 * A <code>ClassFormatError</code> is thrown when a Java Virtual Machine
 * unable to read a class file because the file is corrupted or cannot be
 * interpreted as a class file.
 *
 * @author Brian Jones
 * @status updated to 1.4
 */
public class ClassFormatError extends LinkageError
{
  /**
   * Compatible with JDK 1.0+.
   */
  private static final long serialVersionUID = -8420114879011949195L;

  /**
   * Create an error without a message.
   */
  public ClassFormatError()
  {
  }

  /**
   * Create an error with a message.
   *
   * @param s the message
   */
  public ClassFormatError(String s)
  {
    super(s);
  }
}
